Release History
===============

.. include:: _draft.rst

.. towncrier release notes start

v4.0.0a1
--------
* First version all is brand new.

.. warning::

   The current virtualenv is the second iteration of implementation. From version ``0.5`` all the way to ``3.X``
   we numbered the first iteration. Version ``4.0.0a1`` is a complete rewrite of the package, and as such this release
   history starts from there. The old changelog is still available in the
   `legacy branch documentation <https://tox.readthedocs.io/en/legacy/changelog.html>`_.
